import { Fn2 } from "@thi.ng/api";
/**
 * Higher-order Porter-Duff alpha compositing operator. See
 * thi.ng/porter-duff for reference. Returns an optimized AST function
 * which accepts 2 RGBA colors (`vec4`) and returns blended & clamped
 * result (also `vec4`). All built-in PD operators are defined via this
 * HOF.
 *
 * The two given JS functions are used to extract blending coefficients
 * for src/dest colors and are called with the alpha components of both
 * colors.
 *
 * @param name function name
 * @param fa src coeff fn
 * @param fb dest coeff fn
 */
export declare const porterDuff: (name: string, fa: Fn2<import("@thi.ng/shader-ast").Term<"float">, import("@thi.ng/shader-ast").Term<"float">, import("@thi.ng/shader-ast").Term<"float">>, fb: Fn2<import("@thi.ng/shader-ast").Term<"float">, import("@thi.ng/shader-ast").Term<"float">, import("@thi.ng/shader-ast").Term<"float">>) => import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const ZERO: () => import("@thi.ng/shader-ast").Term<"float">;
export declare const ONE: () => import("@thi.ng/shader-ast").Term<"float">;
export declare const A: (a: import("@thi.ng/shader-ast").Term<"float">) => import("@thi.ng/shader-ast").Term<"float">;
export declare const B: (_: import("@thi.ng/shader-ast").Term<"float">, b: import("@thi.ng/shader-ast").Term<"float">) => import("@thi.ng/shader-ast").Term<"float">;
export declare const ONE_MINUS_A: (a: import("@thi.ng/shader-ast").Term<"float">) => import("@thi.ng/shader-ast").Op2<"float">;
export declare const ONE_MINUS_B: (_: import("@thi.ng/shader-ast").Term<"float">, b: import("@thi.ng/shader-ast").Term<"float">) => import("@thi.ng/shader-ast").Op2<"float">;
export declare const blendSrcOver: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const blendDestOver: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const blendSrcIn: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const blendDestIn: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const blendSrcOut: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const blendDestOut: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const blendSrcAtop: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const blendDestAtop: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const blendXor: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
export declare const blendPlus: import("@thi.ng/shader-ast").TaggedFn2<"vec4", "vec4", "vec4">;
